@@ -1,6 +1,6 @@
 package CHI::Driver::Memcached::Base;
 BEGIN {
-  $CHI::Driver::Memcached::Base::VERSION = '0.13';
+  $CHI::Driver::Memcached::Base::VERSION = '0.14';
 }
 use CHI;
 use Carp;
@@ -27,7 +27,8 @@ sub BUILD {
     $self->{memd_params} ||= $self->non_common_constructor_params($params);
     $self->{memd_params}->{namespace} ||= $self->{namespace} . ":";
     $self->{memd} = $self->{_contained_cache} = $self->_build_contained_cache;
-    $self->{max_key_length} = 248 - length( $self->{namespace} );
+    $self->{max_key_length} = 248 - length( $self->{namespace} )
+      if !defined( $self->{max_key_length} );
 }
 
 sub _build_contained_cache {
